@@ -7,7 +7,7 @@
     'name_es_CO': 'Facturación Analítica',
     'name_es_ES': 'Facturación analítica',
     'name_fr_FR': 'Facturation analytique',
-    'version': '2.0.3',
+    'version': '2.2.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -18,7 +18,7 @@
     'description_de_DE': ''' - Fügt Kostenstellen zu Rechnungszeilen hinzu
  - Erstellt Positionen für Kostenstellen bei Buchung von Rechnungen
 ''',
-    'description_es_CO': ''' - Adición de contabilidad analítica a las líneas de facturación 
+    'description_es_CO': ''' - Adición de contabilidad analítica a las líneas de facturación
  -  Generación de líneas analíticas en la factura.
 ''',
     'description_es_ES': '''Añade una cuenta analítica en las líneas de '''
@@ -35,10 +35,13 @@
         'invoice.xml',
     ],
     'translation': [
-        'bg_BG.csv',
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
+        'locale/bg_BG.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
