@@ -1,29 +1,30 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Not, Equal, Eval
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 
 class InvoiceLine(ModelSQL, ModelView):
     _name = 'account.invoice.line'
 
     analytic_accounts = fields.Many2One('analytic_account.account.selection',
-            'Analytic Accounts',
-            states={
-                'invisible': Not(Equal(Eval('type'), 'line')),
-            })
+        'Analytic Accounts',
+        states={
+            'invisible': Eval('type') != 'line',
+            },
+        depends=['type'])
 
     def _view_look_dom_arch(self, tree, type, field_children=None):
-        analytic_account_obj = self.pool.get('analytic_account.account')
+        analytic_account_obj = Pool().get('analytic_account.account')
         analytic_account_obj.convert_view(tree)
         arch, fields = super(InvoiceLine, self)._view_look_dom_arch(tree, type,
             field_children=field_children)
         return arch, fields
 
     def fields_get(self, fields_names=None):
-        analytic_account_obj = self.pool.get('analytic_account.account')
+        analytic_account_obj = Pool().get('analytic_account.account')
 
         res = super(InvoiceLine, self).fields_get(fields_names)
 
@@ -40,7 +41,7 @@ class InvoiceLine(ModelSQL, ModelView):
             with_rec_name=with_rec_name)
 
     def read(self, ids, fields_names=None):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         int_id = False
         if isinstance(ids, (int, long)):
@@ -90,7 +91,7 @@ class InvoiceLine(ModelSQL, ModelView):
         return res
 
     def create(self, vals):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
         vals = vals.copy()
         selection_vals = {}
         for field in vals.keys():
@@ -107,7 +108,7 @@ class InvoiceLine(ModelSQL, ModelView):
         return super(InvoiceLine, self).create(vals)
 
     def write(self, ids, vals):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
         vals = vals.copy()
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -148,7 +149,7 @@ class InvoiceLine(ModelSQL, ModelView):
         return super(InvoiceLine, self).write(ids, vals)
 
     def delete(self, ids):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -163,7 +164,7 @@ class InvoiceLine(ModelSQL, ModelView):
         return res
 
     def copy(self, ids, default=None):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         new_ids = super(InvoiceLine, self).copy(ids, default=default)
 
@@ -184,7 +185,7 @@ class InvoiceLine(ModelSQL, ModelView):
         return new_ids
 
     def _credit(self, line):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         result = super(InvoiceLine, self)._credit(line)
 
@@ -219,21 +220,21 @@ class Account(ModelSQL, ModelView):
     _name = 'analytic_account.account'
 
     def delete(self, ids):
-        account_invoice_line_obj = self.pool.get('account.invoice.line')
+        account_invoice_line_obj = Pool().get('account.invoice.line')
         res = super(Account, self).delete(ids)
         # Restart the cache on the fields_view_get method of account.invoice.line
         account_invoice_line_obj.fields_view_get.reset()
         return res
 
     def create(self, vals):
-        account_invoice_line_obj = self.pool.get('account.invoice.line')
+        account_invoice_line_obj = Pool().get('account.invoice.line')
         res = super(Account, self).create(vals)
         # Restart the cache on the fields_view_get method of account.invoice.line
         account_invoice_line_obj.fields_view_get.reset()
         return res
 
     def write(self, ids, vals):
-        account_invoice_line_obj = self.pool.get('account.invoice.line')
+        account_invoice_line_obj = Pool().get('account.invoice.line')
         res = super(Account, self).write(ids, vals)
         # Restart the cache on the fields_view_get method of account.invoice.line
         account_invoice_line_obj.fields_view_get.reset()
